SWDEV-353807 - Fixes multiple catch issues (#2912)

- enforcing c++17 for all tests
- Warning as error: ignoring return value

Change-Id: I3d171540403f74222e631d1a8e393386461c9729
This commit is contained in:
ROCm CI Service Account
2022-08-31 05:23:21 +05:30
zatwierdzone przez GitHub
rodzic ba5a0b9af5
commit d0aaed906d
24 zmienionych plików z 100 dodań i 99 usunięć
@@ -53,7 +53,7 @@ TEST_CASE("Unit_hipManagedKeyword_SingleGpu") {
hipLaunchKernelGGL(add, dimGrid, dimBlock, 0, 0, static_cast<const float*>(A),
static_cast<float*>(B));
hipDeviceSynchronize();
HIP_CHECK(hipDeviceSynchronize());
float maxError = 0.0f;
for (int i = 0; i < N; i++)
@@ -64,12 +64,12 @@ TEST_CASE("Unit_hipManagedKeyword_SingleGpu") {
TEST_CASE("Unit_hipManagedKeyword_MultiGpu") {
int numDevices = 0;
hipGetDeviceCount(&numDevices);
HIP_CHECK(hipGetDeviceCount(&numDevices));
for (int i = 0; i < numDevices; i++) {
hipSetDevice(i);
HIP_CHECK(hipSetDevice(i));
GPU_func<<< 1, 1 >>>();
hipDeviceSynchronize();
HIP_CHECK(hipDeviceSynchronize());
}
REQUIRE(x == numDevices);
}